<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use App\Models\Aattachment;

class FileUploadController extends Controller
{
    public function upload(Request $request)
    {
        $request->validate([
            'attachment_custom_name' => 'required|string',
            'files.*' => 'required|file|max:2048|mimes:jpg,jpeg,png,pdf'
        ]);

        // Sanitize folder name to allow only letters, numbers, dashes, and underscores
        $folderName = preg_replace('/[^A-Za-z0-9_-]/', '', $request->attachment_custom_name);
        $path = "product_upload/$folderName"; // Define storage path
        Storage::disk('public')->makeDirectory($path); // Ensure folder exists

        $uploadedFiles = [];

        foreach ($request->file('files') as $file) {
            $fileName = time() . '-' . $file->getClientOriginalName();
            $filePath = $file->storeAs($path, $fileName, 'public'); // Save in storage

            // Save file record in database
            $attachment = Aattachment::create([
                'folder_name' => $folderName,
                'file_name' => $fileName,
                'file_path' => $filePath,
            ]);

            $uploadedFiles[] = [
                'id' => $attachment->id,
                'file_name' => $fileName,
                'file_path' => asset("storage/$filePath"),
            ];
        }

        return response()->json([
            'success' => true,
            'message' => 'Files uploaded successfully!',
            'attachments' => $uploadedFiles
        ]);
    }
}
