<?php

namespace App\Http\Controllers;

use App\Models\Product;
use Illuminate\Http\Request;
use App\Models\AccountHolder;
use App\Models\AccountProfile;
Use App\Models\Aattachment;
Use App\Models\Expense;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use Illuminate\Contracts\Mail\Attachable;
use Symfony\Component\HttpKernel\Profiler\Profile;

class ProductController extends Controller
{
    

    public function add()
    {
        $holders=AccountHolder::all();
        $profiles = AccountProfile::all();
        $Aattachments=Aattachment::all();
        $title = "Add Product";
        $description = "Fill out the details to add a new product.";
    
        return view('products.add', compact('profiles','holders','Aattachments','title', 'description'));
    }
    public function upload($data)
    {
        Log::info('Uppy Upload Request:', $data);

        $attachmentName = trim($data['attachment_custom_name']);

        if (!$attachmentName) {
            return response()->json(['error' => 'Attachment Folder Name is required.'], 400);
        }

        if (!$data['images']) {
            return response()->json(['error' => 'No files received.'], 400);
        }

        // ✅ Set storage folder path inside "storage/app/public/attachments/"
        $folderPath = 'attachments/' . $attachmentName;
        Storage::disk('public')->makeDirectory($folderPath);

        // ✅ Check if folder entry exists in the database
        $attachment = Aattachment::where('attachment_name', $attachmentName)->first();

        if (!$attachment) {
            $attachment = Aattachment::create([
                'attachment_name' => $attachmentName,
                'file_path' => 'storage/' . $folderPath,
                'uploaded_at' => now(),
            ]);
        }
       
        // ✅ Store multiple files inside the same folder
        foreach ($data['images'] as $file) {
            $fileName = time() . '_' . $file->getClientOriginalName();
            $file->storeAs($folderPath, $fileName, 'public');
        }

        return $attachment->id;
    }

    
    public function store(Request $request)
    {
 
        $request->validate([
            'profile_id' => 'nullable|integer',
            'product_name' => 'required|string',
            'product_cost' => 'required|numeric',
            'account_holder' => 'required',
            'email ' => 'nullable|email',
            'password' => 'nullable',
            'recovery_email' => 'nullable|email',
            'account_email' => 'nullable|email',
            'account_password' => 'nullable',
            'number_password' => 'nullable',
            'passcode_pin' => 'nullable|numeric',
            'number_provider' => 'nullable',
            'number' => 'nullable|numeric',
            'number_email' => 'nullable|email',
            'number_password' => 'nullable',
            'proxy' => 'nullable',
            'note' => 'nullable',
            'attachment_custom_name' => 'nullable',
            'attachment_id' => 'nullable|integer',
        ]);

        $data = $request->all();

        # if the profile name is not exist in account profile table
        if (is_null($request->profile_id)) {
            $accountProfile = AccountProfile::create([ 'name' => $request->product_name ]);

            $data['profile_id'] = $accountProfile->id;
        }
        # if the account holder is not exist in account holder table
        if (is_null( $request->account_holder_id ) ) {
            $accountHolder = AccountHolder::create( ['name' => $request->account_holder] );

            $data['account_holder_id'] = $accountHolder->id;
        }

        # For image upload 
        if (!is_null($request->images)) {
            
            $request->validate( [
                'attachment_custom_name' => 'required|string',
                'images'                 => 'required|array', // Must be an array
                'images.*'               => 'file|mimes:jpg,jpeg,png,gif,webp,pdf,doc,docx,xlsx,csv,txt|max:5120', // Validate each file
            ] );

         $data['attachment_id']  = $this->upload($request->only(['attachment_custom_name', 'images']));
        }

        $product = Product::create($data);

        $expense = Expense::create([
            'date' => Carbon::now(), // Current date
            'amount' => $request->product_cost, // Assigning product cost
            'account_heading' => 'Expense', // Static value
            'description' => $request->product_name, // Product name as description
            'reference' => $request->account_holder, // Account holder as reference
            'payment_mode' => 'Cash', // Static value
        ]);

        session()->flash( 'success', 'Product has been added successfully!' );
        return redirect()->route( 'product.stock' );
        // return response()->json([
        //     'status' => 'success',
        //     'message' => 'Product successfully saved!',
        //     'product' => $product,
        //     'expense' => $expense
        // ]);
    }
      public function update(Request $request, $id) {
        $data = $request->all();
        $product = Product::find($id);
       
        # if the profile name is not exist in account profile table
        if ( is_null( $request->profile_id ) ) {
            $accountProfile = AccountProfile::create( ['name' => $request->product_name] );

            $data['profile_id'] = $accountProfile->id;
        }
        # if the account holder is not exist in account holder table
        if ( is_null( $request->account_holder_id ) ) {
            $accountHolder = AccountHolder::create( ['name' => $request->account_holder] );

            $data['account_holder_id'] = $accountHolder->id;
        }

        # For image upload
        if ( !is_null( $request->images ) ) {

            $request->validate( [
                'attachment_custom_name' => 'required|string',
                'images'                 => 'required|array', // Must be an array
                'images.*'               => 'file|mimes:jpg,jpeg,png,gif,webp,pdf,doc,docx,xlsx,csv,txt|max:5120', // Validate each file
            ] );

            $data['attachment_id'] = $this->upload( $request->only( ['attachment_custom_name', 'images'] ) );
        }

        $product->update($data);  

        session()->flash( 'success', 'Update successfully!' );

        return redirect()->route( 'product.stock' );
    }
    public function edit($id){
        $product = Product::find($id);
        $title       = "Product Edit";
        $description = "Product Edit";
        $holders      = AccountHolder::all();
        $profiles     = AccountProfile::all();
        $Aattachments = Aattachment::all();


        return view( 'products.edit', compact('profiles','holders','Aattachments', 'product', 'title', 'description' ) );
    }
    
     public function profileEdit(Request $reqiest){

        return   AccountProfile::find($reqiest->id);
    }


    public function stock()
    {
        $title = "Add Product";
        $description = "Fill out the details to add a new product.";
        
        // Fetch products with the required fields and related account profile
        $products = Product::select(['id','product_name','product_cost','email', 'account_holder', 'is_sold','attachment_id', 'profile_id'])
            ->where('is_sold', 0)
            ->with(['accountProfile:id,name,logo','attachment:id,company_id,attachment_name,file_path'])
            ->latest()
            ->paginate(10);

       return view('products.stock', compact('products', 'title', 'description'));
    }
      public function stockView($id) {
        $product = Product::find($id)->load(['accountProfile:id,name,logo','attachment:id,company_id,attachment_name,file_path']);
        $title       = "Product View";
        $description = "Product View";
        $imagesOrfiles = [];
        $folderUrl = "";
        if(!is_null($product->attachment_id))
        {
            $attachmentView = Aattachment::find( $product?->attachment_id );
            $folderPath     = public_path( $attachmentView?->file_path );
            $folderUrl      = $attachmentView?->file_path;

            // Get all image files (filtering only images)
            $imagesOrfiles = File::files( $folderPath );
        }
        

        return view( 'products.view', compact( 'product', 'title', 'description','imagesOrfiles','folderUrl' ) );
    }

     public function delete($id) {
        $product = Product::find($id);
        $product->delete();
        session()->flash( 'success', 'Delete successfully!' );

        return redirect()->route( 'product.stock' );
    }
    
    public function sold(){
        $title = "sold Product";
        $description = "Fill out the details to add a new product.";

        return view('products.sold', compact('title', 'description'));
    } 

     public function attachmentView($id){
        $title = "AttachmentView";
        $description = "Fill out the details to add a new product.";
        $attachmentView = Aattachment::find($id);
        $folderPath = public_path( $attachmentView?->file_path );
        $folderUrl =  $attachmentView?->file_path;

        // Get all image files (filtering only images)
        $imagesOrfiles = File::files( $folderPath );

        return view('products.attachment-view', compact('title', 'description','imagesOrfiles','folderUrl'));
    } 
   

    public function import(){
        $title = "import Product";
        $description = "Fill out the details to add a new product.";

        return view('products.import', compact('title', 'description'));
    } 


    // public function profileSave(Request $request){
    //     $title = "import Product";
    //     $description = "Fill out the details to add a new product.";
    //     $request->all();
    //     return $request;
    // } 
    public function profile(){
        $profiles = AccountProfile::orderBy('id','DESC')->paginate(10);
        $title = "profile Product";
        $description = "Fill out the details to add a new product.";

        //return $profiles;
        return view('products.profile', compact('title', 'description','profiles'));
    } 
    

    public function profileSave(Request $request)
    {
        try {
            // Validate input
            $request->validate([
                'name' => 'required|string|max:255',
                'geo_location' => 'nullable|string|max:255',
                'logo' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            ]);
    
            // Handle file upload
            if ($request->hasFile('logo')) {
                $fileName = str_replace(' ', '_', strtolower($request->name)) . '.' . $request->file('logo')->getClientOriginalExtension();
                $request->file('logo')->storeAs('public/account_profile', $fileName);
                $logoPath = 'storage/account_profile/' . $fileName;
            } else {
                $logoPath = 'storage/account_profile/default.jpg'; // Default image path
            }
    
            // Save data
            $AccountProfile = AccountProfile::create([
                'name' => $request->name,
                'geo' => $request->geo_location ?? null,
                'logo' => $logoPath,
            ]);
    
            return response()->json([
                'success' => true,
                'message' => 'Project saved successfully!',
                'data' => $AccountProfile
            ], 200);
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }

   public function profileUpdate(Request $request, $id)
    {
        $accountProfile = AccountProfile::findOrFail($id);
        $accountProfile->name = $request->name;
        $accountProfile->geo = $request->geo_location;

        if ($request->hasFile('logo')) {
            // Delete Old Image if Exists
            if ($accountProfile->logo && Storage::exists(str_replace('storage/', 'public/', $accountProfile->logo))) {
                Storage::delete(str_replace('storage/', 'public/', $accountProfile->logo));
            }

            // Save New Image
            $fileName = str_replace(' ', '_', strtolower($request->name)) . '.' . $request->file('logo')->getClientOriginalExtension();
            $path = $request->file('logo')->storeAs('public/account_profile', $fileName);
            $logoPath = 'storage/account_profile/' . $fileName;

            $accountProfile->logo = $logoPath;
        }

        $accountProfile->save();

        return response()->json(['message' => 'Profile updated successfully!']);
    }



public function profiledelete(Request $request)
{
    try {
        // Find profile by ID in AccountProfile model
        $profile = AccountProfile::find($request->id);

        if (!$profile) {
            return response()->json([
                'success' => false,
                'message' => 'Profile not found.'
            ], 404);
        }

        // Delete profile logo if exists in storage
        if ($profile->logo && file_exists(public_path($profile->logo))) {
            unlink(public_path($profile->logo));
        }

        // Delete profile from database
        $profile->delete();

        return response()->json([
            'success' => true,
            'message' => 'Profile deleted successfully!'
        ], 200);
    } catch (\Exception $e) {
        return response()->json([
            'success' => false,
            'message' => 'Error: ' . $e->getMessage()
        ], 500);
    }
}


    

}
