@extends('layout.app')

@section('title', $title)
@section('description', $description)

@section('content')
<div class="container-fluid">
    <div class="row">
        <div class="col-lg-12">
            <div class="breadcrumb-main user-member justify-content-sm-between">
                <div class="d-flex flex-wrap justify-content-center breadcrumb-main__wrapper">
                    <div class="d-flex align-items-center user-member__title justify-content-center me-sm-25">
                        <h4 class="text-capitalize fw-500 breadcrumb-title">{{ trans('menu.user-table') }}</h4>
                        <span class="sub-title ms-sm-25 ps-sm-25">Home</span>
                    </div>

                    <form action="/" class="d-flex align-items-center user-member__form my-sm-0 my-2">
                        <img src="{{ asset('assets/img/svg/search.svg') }}" alt="search" class="svg">
                        <input class="form-control me-sm-2 border-0 box-shadow-none" type="search" placeholder="Search by Name" aria-label="Search">
                    </form>
                </div>
                <div class="action-btn">
                    <a href="{{ route('user-admin.add') }}" class="btn px-15 btn-primary">
                        <i class="las la-plus fs-16"></i> Add New User
                    </a>
                </div>
            </div>
        </div>
    </div>

    <!-- User Data Table -->
    <div class="row">
        <div class="col-lg-12">
            @if (session('success'))
                <div class="alert alert-success">
                    {{ session('success') }}
                </div>
            @endif
            <div class="userDatatable global-shadow border-light-0 p-30 bg-white radius-xl w-100 mb-30">
                <div class="table-responsive">
                    <table class="table mb-0 table-borderless">
                        <thead>
                            <tr class="userDatatable-header">
                                <th>Username</th>
                                <th>Email</th>
                                <th>Role</th>
                                <th>Status</th>
                                <th class="float-end">Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach($users as $user)
                                <tr>
                                    <td>
                                        <div class="d-flex">
                                            <div class="userDatatable-inline-title">
                                                <h6>{{ $user->username }}</h6>
                                               
                                            </div>
                                        </div>
                                    </td>
                                    <td><div class="userDatatable-content">{{ $user->email }}</div></td>
                                    <td><div class="userDatatable-content">{{ ucfirst($user->role) }}</div></td>
                                    <td>
                                        <div class="userDatatable-content d-inline-block">
                                            @if($user->status == '1')
                                                <span class="bg-opacity-success color-success rounded-pill userDatatable-content-status">Active</span>
                                            @else
                                                <span class="bg-opacity-danger color-danger rounded-pill userDatatable-content-status">Inactive</span>
                                            @endif
                                        </div>
                                    </td>
                                    <td>
                                        <ul class="orderDatatable_actions mb-0 d-flex flex-wrap">
                                            <li>
                                                <a href="{{route('user-admin.view', $user->id)}}" class="view">
                                                    <i class="uil uil-eye"></i>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="{{route('user-admin.edit', $user->id)}}" class="edit">
                                                    <i class="uil uil-edit"></i>
                                                </a>
                                            </li>
                                            <li>
                                                <a href="{{route('user-admin.delete', $user->id)}}" class="edit">
                                                    <i class="uil uil-trash-alt"></i>
                                                </a>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                    @if($users->isEmpty())
                        <p class="text-center text-muted mt-3">No users found.</p>
                    @endif
                </div>
            </div>
        </div>
    </div>

    <!-- Pagination -->
   
@endsection
