<?php

use App\Models\Customer;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\PosController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\AccountsController;
use App\Http\Controllers\CustomerController;
use App\Http\Controllers\LanguageController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\PaginationController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::group(['middleware'=>'guest'],function(){
    Route::get('/',[AuthController::class,'login'])->name('login');
    Route::get('/register',[AuthController::class,'register'])->name('register');
    Route::get('/forget-password',[AuthController::class,'forgetPassword'])->name('forget_password');
    Route::post('/authenticate',[AuthController::class,'authenticate'])->name('authenticate');
    Route::post('/signup',[AuthController::class,'signup'])->name('signup');
});

Route::post('/logout',[AuthController::class,'logout'])->name('logout')->middleware('auth');
Route::get('/lang/{lang}',[ LanguageController::class,'switchLang'])->name('switch_lang');
Route::get('/pagination-per-page/{per_page}',[ PaginationController::class,'set_pagination_per_page'])->name('pagination_per_page');

// User in admin dashboard it's call admin
Route::get('/user/table', [UserController::class, 'table'])->name('user.table'); 
Route::get('/user/add', [UserController::class, 'add'])->name('user-admin.add'); 
Route::post('/user/store', [UserController::class, 'store'])->name('user-admin.store'); 
Route::get('/user/edit/{id}', [UserController::class, 'edit'])->name('user-admin.edit'); 
Route::post('/user/update/{id}', [UserController::class, 'update'])->name('user-admin.update'); 
Route::get('/user/view/{id}', [UserController::class, 'view'])->name('user-admin.view'); 
Route::get('/user/delete/{id}', [UserController::class, 'delete'])->name('user-admin.delete'); 

Route::group(['middleware'=>'auth'], function() {
    Route::group(['prefix'=>'dashboard','as'=>'dashboard.'], function() {
        Route::get('/', [DashboardController::class, 'index'])->name('/');
    });
});

Route::get('/product/add',[ ProductController::class,'add'])->name('add');
Route::post('/product/store', [ProductController::class, 'store'])->name('product.store');
Route::post('/upload', [ProductController::class, 'upload']);

Route::get('/product/stock', [ProductController::class, 'stock'])->name('product.stock');
Route::get('/product/edit/{id}', [ProductController::class, 'edit'])->name('product.edit');
Route::post('/product/update/{id}', [ProductController::class, 'update'])->name('product.update');
Route::get('/product/stock/delete/{id}', [ProductController::class, 'delete'])->name('product.delete');
Route::get('/product/stock/{id}', [ProductController::class, 'stockView'])->name('product.stock_view');
Route::get( '/product/stock/attachment/{id}', [ProductController::class, 'attachmentView'] )->name( 'product.attachment_view' );
Route::get('/product/sold', [ProductController::class, 'sold'])->name('product.sold');

Route::get('/product/profile', [ProductController::class, 'profile'])->name('product.profile');
Route::get('/product/profile/edit/{id}', [ProductController::class, 'profileEdit'])->name('product.profile_edit');
Route::get('/product/import', [ProductController::class, 'import'])->name('product.import');
Route::post('/product/profile', [ProductController::class, 'profileSave'])->name('product.profilesave');
Route::post('/product/profile/update/{id}', [ProductController::class, 'profileUpdate'])->name('product.profile_update');
Route::DELETE('/product/profile/delete', [ProductController::class, 'profiledelete'])->name('product.profiledelete');

//customer route
Route::get('/customer', [CustomerController::class, 'index'])->name('customer.list');
//Income Route
Route::get('/accounts/income',[ AccountsController::class,'incomeindex'])->name('account.income');
Route::DELETE('/accounts/income/delete/{id}', [AccountsController::class,'income_destroy'])->name('accounts.income.delete');
//expense Route
Route::get('/accounts/expense',[ AccountsController::class,'expenseindex'])->name('account.expense');
Route::DELETE('/accounts/expense/delete/{id}', [AccountsController::class,'expense_destroy'])->name('accounts.expense.delete');
//Headings route
Route::post('/accounts/headings/store',[ AccountsController::class,'headingstore'])->name('account.headings.store');
Route::get('/accounts/headings',[ AccountsController::class,'headingsindex'])->name('account.headings');
Route::DELETE('/accounts/headings/delete', [AccountsController::class, 'headingdelete'])->name('accounts.heading.delete');

//Payment mode route
Route::get('/accounts/payments',[ AccountsController::class,'paymentsindex'])->name('account.payments');
Route::post('/accounts/payments/store',[ AccountsController::class,'paymentstore'])->name('account.payment.store');
Route::DELETE('/accounts/payments/delete', [AccountsController::class, 'paymentdelete'])->name('accounts.payment.delete');

// For POS
Route::get('pos',[PosController::class, 'showUI'])->name('pos.ui');